import { IBaseClient } from './interfaces.js';
import { HttpMethods, QueryType, RequestInitType } from './types.js';
/**
 * BaseClient serves as the base class for API clients.
 * Provides basic functionalities for making HTTP requests to a server.
 */
export declare abstract class BaseClient implements IBaseClient {
    readonly host: string;
    protected readonly reqInit: RequestInit | undefined;
    /**
     * @param host - The server's address.
     * @param reqInit - Optional default request initializer.
     */
    protected constructor(host: string, reqInit?: RequestInit | undefined);
    fetch(path: string, query?: QueryType, init?: RequestInit): Promise<{
        uri: string;
        res: Response;
        req: RequestInit;
    }>;
    get(path: string, query?: QueryType, init?: RequestInitType): Promise<Response>;
    put(path: string, query?: QueryType, init?: RequestInitType): Promise<Response>;
    delete(path: string, query?: QueryType, init?: RequestInitType): Promise<Response>;
    post(path: string, query?: QueryType, init?: RequestInitType): Promise<Response>;
    text(path: string, query?: QueryType, init?: RequestInit): Promise<string>;
    json<T extends object>(path: string, query?: QueryType, init?: RequestInit): Promise<T>;
    method(method: HttpMethods, path: string, query?: QueryType, init?: RequestInitType): Promise<Response>;
    /**
     * Constructs a URI path by joining URI components.
     * @param paths - Paths to encode and join.
     * @returns encoded URI path.
     */
    getPath(...paths: string[]): string;
    /**
     * Constructs a URI by appending a path to the host.
     * @param path - The path to append to the host.
     * @returns URI string.
     */
    getUri(path: string): string;
    /**
     * Handles text responses from the server.
     * @param req - The request object.
     * @param res - The response object.
     * @param uri - The request URI.
     * @returns Promise that resolves with the text data.
     */
    protected handleText({ req, res, uri, }: {
        req: RequestInit;
        res: Response;
        uri: string;
    }): Promise<string>;
    /**
     * Handles JSON responses from the server.
     * @param req - The request object.
     * @param res - The response object.
     * @param uri - The request URI.
     * @returns Promise that resolves with the JSON data.
     */
    protected handleJson<T>({ req, res, uri, }: {
        req: RequestInit;
        res: Response;
        uri: string;
    }): Promise<T>;
}
//# sourceMappingURL=baseClient.d.ts.map