import { ErrorResponseType, HttpMethods, QueryType, RequestInitType } from './types.js';
/**
 * The `IBaseClient` interface outlines the structure for a base client with basic configurations for making HTTP requests.
 */
export interface IBaseClient {
    /**
     * The server's address to which the client makes requests.
     */
    readonly host: string;
    /**
     * Fetches a response from the given path.
     * @param path - The path of the resource.
     * @param query - Optional query.
     * @param init - Optional request initializer. Overwrites default settings.
     */
    fetch(path: string, query?: QueryType, init?: RequestInit): Promise<{
        uri: string;
        res: Response;
    }>;
    /**
     * Gets a response from the given path.
     * @param path - The path of the resource.
     * @param query - Optional query.
     * @param init - Optional request initializer. Overwrites default settings.
     */
    get(path: string, query?: QueryType, init?: RequestInit): Promise<Response>;
    /**
     * Posts a request and gets a response from the given path.
     * @param path - The path of the resource.
     * @param query - Optional query.
     * @param init - Optional request initializer. Overwrites default settings.
     * @returns Promise that resolves with the JSON data.
     */
    post(path: string, query?: QueryType, init?: RequestInitType): Promise<Response>;
    /**
     * Fetches a resource as text from the given path.
     * @param path - The path of the resource.
     * @param query - Optional query.
     * @param init - Optional request initializer. Overwrites default settings.
     * @returns Promise that resolves with the text data.
     */
    text(path: string, query?: QueryType, init?: RequestInit): Promise<string>;
    /**
     * Fetches a resource as JSON from the given path.
     * @param path - The path of the resource.
     * @param query - Optional query.
     * @param init - Optional request initializer. Overwrites default settings.
     * @returns Promise that resolves with the JSON data.
     */
    json<T extends object>(path: string, query?: QueryType, init?: RequestInit): Promise<T>;
    /**
     * Fetches a response, using the given path and method.
     * @param method = Http method of the request.
     * @param path - The path of the resource.
     * @param query - Optional query.
     * @param init - Optional request initializer. Overwrites default settings.
     */
    method(method: HttpMethods, path: string, query?: QueryType, init?: RequestInitType): Promise<Response>;
    /**
     * Constructs a URI path by joining URI components.
     * @param paths - Paths to encode and join.
     * @returns encoded URI path.
     */
    getPath(...paths: string[]): string;
    /**
     * Constructs a URI by appending a path to the host.
     * @param path - The path to append to the host.
     * @returns URI string.
     */
    getUri(path: string): string;
}
/**
 * Outlines the structure for a custom error type to handle client errors.
 * It extends the built-in Error interface.
 */
export interface IClientError extends Error {
    /**
     * `BaseClient` that is associated with the error.
     */
    readonly client: IBaseClient;
    /**
     * Response received from the server that caused the error.
     */
    readonly response: ErrorResponseType;
    /**
     * Optional request that was sent which caused the error.
     */
    readonly request?: RequestInit;
    /**
     * Optional URI to which the request was sent.
     */
    readonly uri?: string;
}
//# sourceMappingURL=interfaces.d.ts.map